<?php
/** 
 * Perform a Flickr search given a search tag
 * The uri generated is something like 
 * http://api.flickr.com/services/rest/?method=flickr.photos.search&api_key=1234567890123456789&tags=flowers&per_page=25
 **/
function flickr_search($search_tag) {
	 // set up the API url
	 $uri = 'http://api.flickr.com/services/rest/?method=flickr.photos.search';
	 $uri .= '&api_key='.zget('/config/flickr/key');
	 $uri .= "&tags=$search_tag";
	 $uri .= "&per_page=".zget('/config/flickr/photos_per_page');
	
	 // call the API
	 $result = connection_get($uri, array());
	 $photo_collection = array();
	 // process the response
	 $rsp = xml_decode($result['body']);	
	 if ($rsp['stat'] == 'ok') {
	    // we are good - convert the response into resource references
	    $photos = $rsp->photos[0];
	    $photo_cnt = count($photos->photo);
	    for ($i = 0; $i < $photo_cnt; $i++) {
	    	$photo = $photos->photo[$i];
		$photo_collection[] = make_resource($photo); 
	    }
	 } else {
		error_log("Flickr response not ok");
	 }
	 return $photo_collection;
}

/**
 * Create a resource given a flickr photo object
 * The photo object is derived from an XML like the following
 * <rsp stat="ok">
	<photos page="1" pages="93468" perpage="25" total="2336700">
		<photo id="2471743047" owner="32786356@N00" secret="04f424f6e1" server="2140" farm="3" title="pinked" ispublic="1" isfriend="0" isfamily="0"/>
 * The photo gif for instance will have the following URL
 * http://farm{farm-id}.static.flickr.com/{server-id}/{id}_{secret}_[mstb].jpg
 **/
function make_resource($photo) {
	 $base_url = 'http://farm'.$photo['farm'].'.static.flickr.com/'.$photo['server'].'/'.
        $photo['id'].'_'.$photo['secret'].'_';
	 $tnail = $base_url.'t.jpg';
	 $image = $base_url.'m.jpg';
	 $owner = $photo['owner'];
	 $title = $photo['title'];
	 return array('title' => $title, 'owner'=>$owner, 'tnail'=>$tnail, 'image'=>$image);
}

?>
